aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2010-11-06 23:13:39 +0100
committerSven Gothel <[email protected]>2010-11-06 23:13:39 +0100
commit6f2d046c8d532db94f6af5003e341104d5bf4aff (patch)
tree723c31b8f9c1097ae48486acbf68e4e06fab2517
parentec6d61f4597af32c22319c4bda3c9dd9ab80bf25 (diff)
Renamed com.sun.gluegen -> com.jogamp.gluegen
-rwxr-xr-xmake/Manifest2
-rw-r--r--make/build-junit.xml10
-rwxr-xr-xmake/build.xml20
-rwxr-xr-xmake/validate-properties.xml2
-rw-r--r--src/java/com/jogamp/gluegen/ArrayTypes.java (renamed from src/java/com/sun/gluegen/ArrayTypes.java)2
-rw-r--r--src/java/com/jogamp/gluegen/CMethodBindingEmitter.java (renamed from src/java/com/sun/gluegen/CMethodBindingEmitter.java)4
-rw-r--r--src/java/com/jogamp/gluegen/CodeGenUtils.java (renamed from src/java/com/sun/gluegen/CodeGenUtils.java)2
-rw-r--r--src/java/com/jogamp/gluegen/CommentEmitter.java (renamed from src/java/com/sun/gluegen/CommentEmitter.java)2
-rw-r--r--src/java/com/jogamp/gluegen/ConstantDefinition.java (renamed from src/java/com/sun/gluegen/ConstantDefinition.java)2
-rw-r--r--src/java/com/jogamp/gluegen/DebugEmitter.java (renamed from src/java/com/sun/gluegen/DebugEmitter.java)4
-rw-r--r--src/java/com/jogamp/gluegen/FunctionEmitter.java (renamed from src/java/com/sun/gluegen/FunctionEmitter.java)2
-rw-r--r--src/java/com/jogamp/gluegen/GlueEmitter.java (renamed from src/java/com/sun/gluegen/GlueEmitter.java)4
-rw-r--r--src/java/com/jogamp/gluegen/GlueEmitterControls.java (renamed from src/java/com/sun/gluegen/GlueEmitterControls.java)2
-rw-r--r--src/java/com/jogamp/gluegen/GlueGen.java (renamed from src/java/com/sun/gluegen/GlueGen.java)12
-rw-r--r--src/java/com/jogamp/gluegen/JavaConfiguration.java (renamed from src/java/com/sun/gluegen/JavaConfiguration.java)14
-rw-r--r--src/java/com/jogamp/gluegen/JavaEmitter.java (renamed from src/java/com/sun/gluegen/JavaEmitter.java)6
-rw-r--r--src/java/com/jogamp/gluegen/JavaMethodBindingEmitter.java (renamed from src/java/com/sun/gluegen/JavaMethodBindingEmitter.java)6
-rw-r--r--src/java/com/jogamp/gluegen/JavaType.java (renamed from src/java/com/sun/gluegen/JavaType.java)4
-rw-r--r--src/java/com/jogamp/gluegen/Logging.java (renamed from src/java/com/sun/gluegen/Logging.java)2
-rw-r--r--src/java/com/jogamp/gluegen/MethodBinding.java (renamed from src/java/com/sun/gluegen/MethodBinding.java)6
-rw-r--r--src/java/com/jogamp/gluegen/ReferencedStructs.java (renamed from src/java/com/sun/gluegen/ReferencedStructs.java)4
-rw-r--r--src/java/com/jogamp/gluegen/StructLayout.java (renamed from src/java/com/sun/gluegen/StructLayout.java)4
-rw-r--r--src/java/com/jogamp/gluegen/SymbolFilter.java (renamed from src/java/com/sun/gluegen/SymbolFilter.java)8
-rw-r--r--src/java/com/jogamp/gluegen/TypeInfo.java (renamed from src/java/com/sun/gluegen/TypeInfo.java)2
-rw-r--r--src/java/com/jogamp/gluegen/ant/GlueGenTask.java (renamed from src/java/com/sun/gluegen/ant/GlueGenTask.java)14
-rw-r--r--src/java/com/jogamp/gluegen/ant/StaticGLGenTask.java (renamed from src/java/com/sun/gluegen/ant/StaticGLGenTask.java)14
-rw-r--r--src/java/com/jogamp/gluegen/cgram/CSymbolTable.java (renamed from src/java/com/sun/gluegen/cgram/CSymbolTable.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/CToken.java (renamed from src/java/com/sun/gluegen/cgram/CToken.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/Define.java (renamed from src/java/com/sun/gluegen/cgram/Define.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/GnuCEmitter.g (renamed from src/java/com/sun/gluegen/cgram/GnuCEmitter.g)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/GnuCParser.g (renamed from src/java/com/sun/gluegen/cgram/GnuCParser.g)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/GnuCTreeParser.g (renamed from src/java/com/sun/gluegen/cgram/GnuCTreeParser.g)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/HeaderParser.g (renamed from src/java/com/sun/gluegen/cgram/HeaderParser.g)4
-rw-r--r--src/java/com/jogamp/gluegen/cgram/LineObject.java (renamed from src/java/com/sun/gluegen/cgram/LineObject.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/PreprocessorInfoChannel.java (renamed from src/java/com/sun/gluegen/cgram/PreprocessorInfoChannel.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/StdCParser.g (renamed from src/java/com/sun/gluegen/cgram/StdCParser.g)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/TNode.java (renamed from src/java/com/sun/gluegen/cgram/TNode.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/TNodeFactory.java (renamed from src/java/com/sun/gluegen/cgram/TNodeFactory.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/ArrayType.java (renamed from src/java/com/sun/gluegen/cgram/types/ArrayType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/BitType.java (renamed from src/java/com/sun/gluegen/cgram/types/BitType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/CVAttributes.java (renamed from src/java/com/sun/gluegen/cgram/types/CVAttributes.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/CompoundType.java (renamed from src/java/com/sun/gluegen/cgram/types/CompoundType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/CompoundTypeKind.java (renamed from src/java/com/sun/gluegen/cgram/types/CompoundTypeKind.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/DoubleType.java (renamed from src/java/com/sun/gluegen/cgram/types/DoubleType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/EnumType.java (renamed from src/java/com/sun/gluegen/cgram/types/EnumType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/Field.java (renamed from src/java/com/sun/gluegen/cgram/types/Field.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/FloatType.java (renamed from src/java/com/sun/gluegen/cgram/types/FloatType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/FunctionSymbol.java (renamed from src/java/com/sun/gluegen/cgram/types/FunctionSymbol.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/FunctionType.java (renamed from src/java/com/sun/gluegen/cgram/types/FunctionType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/IntType.java (renamed from src/java/com/sun/gluegen/cgram/types/IntType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/MachineDescription.java (renamed from src/java/com/sun/gluegen/cgram/types/MachineDescription.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/MachineDescription32Bit.java (renamed from src/java/com/sun/gluegen/cgram/types/MachineDescription32Bit.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/MachineDescription64Bit.java (renamed from src/java/com/sun/gluegen/cgram/types/MachineDescription64Bit.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/PointerType.java (renamed from src/java/com/sun/gluegen/cgram/types/PointerType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/PrimitiveType.java (renamed from src/java/com/sun/gluegen/cgram/types/PrimitiveType.java)2
-rwxr-xr-xsrc/java/com/jogamp/gluegen/cgram/types/SizeThunk.java (renamed from src/java/com/sun/gluegen/cgram/types/SizeThunk.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/Type.java (renamed from src/java/com/sun/gluegen/cgram/types/Type.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/TypeDictionary.java (renamed from src/java/com/sun/gluegen/cgram/types/TypeDictionary.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/TypeVisitor.java (renamed from src/java/com/sun/gluegen/cgram/types/TypeVisitor.java)2
-rw-r--r--src/java/com/jogamp/gluegen/cgram/types/VoidType.java (renamed from src/java/com/sun/gluegen/cgram/types/VoidType.java)2
-rw-r--r--src/java/com/jogamp/gluegen/jgram/JavaParser.g (renamed from src/java/com/sun/gluegen/jgram/JavaParser.g)2
-rw-r--r--src/java/com/jogamp/gluegen/jgram/Test.java (renamed from src/java/com/sun/gluegen/jgram/Test.java)4
-rwxr-xr-xsrc/java/com/jogamp/gluegen/nativesig/NativeSignatureEmitter.java (renamed from src/java/com/sun/gluegen/nativesig/NativeSignatureEmitter.java)14
-rwxr-xr-xsrc/java/com/jogamp/gluegen/nativesig/NativeSignatureJavaMethodBindingEmitter.java (renamed from src/java/com/sun/gluegen/nativesig/NativeSignatureJavaMethodBindingEmitter.java)13
-rwxr-xr-xsrc/java/com/jogamp/gluegen/pcpp/ConcatenatingReader.java (renamed from src/java/com/sun/gluegen/pcpp/ConcatenatingReader.java)2
-rw-r--r--src/java/com/jogamp/gluegen/pcpp/PCPP.java (renamed from src/java/com/sun/gluegen/pcpp/PCPP.java)2
-rwxr-xr-xsrc/java/com/jogamp/gluegen/procaddress/ProcAddressCMethodBindingEmitter.java (renamed from src/java/com/sun/gluegen/procaddress/ProcAddressCMethodBindingEmitter.java)9
-rwxr-xr-xsrc/java/com/jogamp/gluegen/procaddress/ProcAddressConfiguration.java (renamed from src/java/com/sun/gluegen/procaddress/ProcAddressConfiguration.java)5
-rwxr-xr-xsrc/java/com/jogamp/gluegen/procaddress/ProcAddressEmitter.java (renamed from src/java/com/sun/gluegen/procaddress/ProcAddressEmitter.java)15
-rwxr-xr-xsrc/java/com/jogamp/gluegen/procaddress/ProcAddressJavaMethodBindingEmitter.java (renamed from src/java/com/sun/gluegen/procaddress/ProcAddressJavaMethodBindingEmitter.java)7
-rw-r--r--test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java6
-rw-r--r--test/junit/com/sun/gluegen/BasicTest.java4
-rw-r--r--test/junit/com/sun/gluegen/BuildUtil.java6
-rw-r--r--test/junit/com/sun/gluegen/PCPPTest.java4
-rw-r--r--test/junit/com/sun/gluegen/StructAccessorTest.java8
-rw-r--r--test/junit/com/sun/gluegen/StructValidator.java4
-rw-r--r--test/junit/com/sun/gluegen/build.xml4
77 files changed, 177 insertions, 156 deletions
diff --git a/make/Manifest b/make/Manifest
index 1677feb..6dd4840 100755
--- a/make/Manifest
+++ b/make/Manifest
@@ -1,2 +1,2 @@
-Main-Class: com.sun.gluegen.GlueGen
+Main-Class: com.jogamp.gluegen.GlueGen
Class-Path: antlr.jar
diff --git a/make/build-junit.xml b/make/build-junit.xml
index 82f87a1..7c70200 100644
--- a/make/build-junit.xml
+++ b/make/build-junit.xml
@@ -87,9 +87,9 @@
<echo message="build_t.lib: ${build_t.lib} "/>
<!-- Add the GlueGen and BuildStaticGLInfo tasks to ANT -->
- <taskdef name="gluegen" classname="com.sun.gluegen.ant.GlueGenTask"
+ <taskdef name="gluegen" classname="com.jogamp.gluegen.ant.GlueGenTask"
classpathref="gluegen.classpath" />
- <taskdef name="staticglgen" classname="com.sun.gluegen.ant.StaticGLGenTask"
+ <taskdef name="staticglgen" classname="com.jogamp.gluegen.ant.StaticGLGenTask"
classpathref="gluegen.classpath" />
</target>
@@ -259,7 +259,7 @@
config="${test.junit.generation.dir}/test1-gluegen.cfg"
literalInclude="${test.junit.generation.dir}"
includeRefid="stub.includes.fileset.test"
- emitter="com.sun.gluegen.JavaEmitter">
+ emitter="com.jogamp.gluegen.JavaEmitter">
<classpath refid="gluegen.classpath" />
</gluegen>
@@ -268,7 +268,7 @@
config="${test.junit.generation.dir}/test1p1-gluegen.cfg"
literalInclude="${test.junit.generation.dir}"
includeRefid="stub.includes.fileset.test"
- emitter="com.sun.gluegen.JavaEmitter">
+ emitter="com.jogamp.gluegen.JavaEmitter">
<classpath refid="gluegen.classpath" />
</gluegen>
@@ -277,7 +277,7 @@
config="${test.junit.generation.dir}/test1p2-gluegen.cfg"
literalInclude="${test.junit.generation.dir}"
includeRefid="stub.includes.fileset.test"
- emitter="com.sun.gluegen.procaddress.ProcAddressEmitter">
+ emitter="com.jogamp.gluegen.procaddress.ProcAddressEmitter">
<classpath refid="gluegen.classpath" />
</gluegen>
</target>
diff --git a/make/build.xml b/make/build.xml
index 113614f..9638c96 100755
--- a/make/build.xml
+++ b/make/build.xml
@@ -35,7 +35,7 @@
</target>
<target name="setup-excludes-2" unless="gluegen.nsig">
- <property name="gluegen.excludes" value="com/jogamp/gluegen/runtime/BufferFactoryInternal.java,com/sun/gluegen/nativesig/**" />
+ <property name="gluegen.excludes" value="com/jogamp/gluegen/runtime/BufferFactoryInternal.java,com/jogamp/gluegen/nativesig/**" />
</target>
<target name="init" depends="gluegen.properties.load.user,setup-excludes-1,setup-excludes-2">
@@ -77,13 +77,13 @@
</path>
<!-- The location of the GlueGen source and the C grammar files. -->
- <property name="gluegen" value="${src.java}/com/sun/gluegen" />
+ <property name="gluegen" value="${src.java}/com/jogamp/gluegen" />
<property name="c.grammar" value="${gluegen}/cgram" />
<property name="j.grammar" value="${gluegen}/jgram" />
<!-- The resulting location of the generated Java files from the
- C grammar via ANTLR. -->
- <property name="gluegen.build" value="${src.generated.java}/com/sun/gluegen" />
+ <property name="gluegen.build" value="${src.generated.java}/com/jogamp/gluegen" />
<property name="generated.java.from.c.grammar" value="${gluegen.build}/cgram" />
<property name="generated.java.from.j.grammar" value="${gluegen.build}/jgram" />
</target>
@@ -142,26 +142,26 @@
<pathelement location="${antlr.jar}" />
</path>
<!-- Define the GlueGen task we just built -->
- <taskdef name="gluegen" classname="com.sun.gluegen.ant.GlueGenTask"
+ <taskdef name="gluegen" classname="com.jogamp.gluegen.ant.GlueGenTask"
classpathref="gluegen.classpath" />
<!-- Execute it against all of the OSs' header files -->
<gluegen src="stub_includes/windows/dynamic-linker.h"
config="dynlink-windows.cfg"
includeRefId="stub.includes.fileset.windows"
- emitter="com.sun.gluegen.JavaEmitter">
+ emitter="com.jogamp.gluegen.JavaEmitter">
<classpath refid="gluegen.classpath" />
</gluegen>
<gluegen src="stub_includes/unix/dynamic-linker.h"
config="dynlink-unix.cfg"
includeRefId="stub.includes.fileset.unix"
- emitter="com.sun.gluegen.JavaEmitter">
+ emitter="com.jogamp.gluegen.JavaEmitter">
<classpath refid="gluegen.classpath" />
</gluegen>
<gluegen src="stub_includes/macosx/dynamic-linker.h"
config="dynlink-macosx.cfg"
includeRefId="stub.includes.fileset.macosx"
- emitter="com.sun.gluegen.JavaEmitter">
+ emitter="com.jogamp.gluegen.JavaEmitter">
<classpath refid="gluegen.classpath" />
</gluegen>
</target>
@@ -410,7 +410,7 @@
<copy todir="${classes-cdc}">
<fileset dir="${classes}"
includes="com/** net/**"
- excludes="com/jogamp/gluegen/runtime/** com/sun/gluegen/test/**" />
+ excludes="com/jogamp/gluegen/runtime/** com/jogamp/gluegen/test/**" />
</copy>
<!-- bootclasspath="${javac.bootclasspath-cdc.jar}"-->
@@ -612,7 +612,6 @@
<jar destfile="${build}/gluegen-rt.jar" manifest="${build}/Manifest-rt.temp">
<fileset dir="${classes}">
<include name="com/jogamp/gluegen/runtime/*.class" />
- <include name="com/jogamp/gluegen/runtime/opengl/*.class" />
<include name="com/jogamp/common/**" />
</fileset>
</jar>
@@ -630,7 +629,6 @@
<jar destfile="${build}/gluegen-rt-cdc.jar" manifest="${build}/Manifest-rt-cdc.temp">
<fileset dir="${classes-cdc}">
<include name="com/jogamp/gluegen/runtime/*.class" />
- <include name="com/jogamp/gluegen/runtime/opengl/*.class" />
<include name="com/jogamp/common/impl/*.class" />
<include name="com/jogamp/common/jvm/*.class" />
<include name="com/jogamp/common/util/*.class" />
@@ -682,7 +680,7 @@
<jvmarg value="-Dgluegen.user.compiler.file=${gluegen.user.compiler.file}"/>
<batchtest todir="${build}/test/results">
<fileset dir="${build}/test/build/classes">
- <include name="com/sun/gluegen/**Test*"/>
+ <include name="com/jogamp/gluegen/**Test*"/>
<include name="com/jogamp/common/nio/**Test*"/>
<include name="com/jogamp/common/util/**Test*"/>
<include name="com/jogamp/common/util/locks/**Test*"/>
diff --git a/make/validate-properties.xml b/make/validate-properties.xml
index 42fd16f..9d29bc8 100755
--- a/make/validate-properties.xml
+++ b/make/validate-properties.xml
@@ -11,7 +11,7 @@
- we can not overwrite it.
-->
<target name="java.class.path.validate">
- <available property="gluegen.jar.on.class.path" classname="com.sun.gluegen.GlueGen" />
+ <available property="gluegen.jar.on.class.path" classname="com.jogamp.gluegen.GlueGen" />
<fail if="gluegen.jar.on.class.path">
*******************************************************************
** Your CLASSPATH environment variable appears to be set (some **
diff --git a/src/java/com/sun/gluegen/ArrayTypes.java b/src/java/com/jogamp/gluegen/ArrayTypes.java
index d943a8a..78122f1 100644
--- a/src/java/com/sun/gluegen/ArrayTypes.java
+++ b/src/java/com/jogamp/gluegen/ArrayTypes.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.nio.*;
diff --git a/src/java/com/sun/gluegen/CMethodBindingEmitter.java b/src/java/com/jogamp/gluegen/CMethodBindingEmitter.java
index d37caaf..ba2eb17 100644
--- a/src/java/com/sun/gluegen/CMethodBindingEmitter.java
+++ b/src/java/com/jogamp/gluegen/CMethodBindingEmitter.java
@@ -37,13 +37,13 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.util.*;
import java.io.*;
import java.text.MessageFormat;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.types.*;
import java.util.logging.Logger;
import static java.util.logging.Level.*;
diff --git a/src/java/com/sun/gluegen/CodeGenUtils.java b/src/java/com/jogamp/gluegen/CodeGenUtils.java
index ac2e033..1b28eb8 100644
--- a/src/java/com/sun/gluegen/CodeGenUtils.java
+++ b/src/java/com/jogamp/gluegen/CodeGenUtils.java
@@ -36,7 +36,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.io.*;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/CommentEmitter.java b/src/java/com/jogamp/gluegen/CommentEmitter.java
index e5fdc6f..89db474 100644
--- a/src/java/com/sun/gluegen/CommentEmitter.java
+++ b/src/java/com/jogamp/gluegen/CommentEmitter.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.io.*;
diff --git a/src/java/com/sun/gluegen/ConstantDefinition.java b/src/java/com/jogamp/gluegen/ConstantDefinition.java
index eee5781..4216b52 100644
--- a/src/java/com/sun/gluegen/ConstantDefinition.java
+++ b/src/java/com/jogamp/gluegen/ConstantDefinition.java
@@ -31,7 +31,7 @@
*
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/DebugEmitter.java b/src/java/com/jogamp/gluegen/DebugEmitter.java
index 06fba30..22cc0c5 100644
--- a/src/java/com/sun/gluegen/DebugEmitter.java
+++ b/src/java/com/jogamp/gluegen/DebugEmitter.java
@@ -37,11 +37,11 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.util.*;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.types.*;
/** Debug emitter which prints the parsing results to standard output. */
diff --git a/src/java/com/sun/gluegen/FunctionEmitter.java b/src/java/com/jogamp/gluegen/FunctionEmitter.java
index a9bfc5a..f9fbd21 100644
--- a/src/java/com/sun/gluegen/FunctionEmitter.java
+++ b/src/java/com/jogamp/gluegen/FunctionEmitter.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.util.*;
import java.io.*;
diff --git a/src/java/com/sun/gluegen/GlueEmitter.java b/src/java/com/jogamp/gluegen/GlueEmitter.java
index 94d8981..5f627f9 100644
--- a/src/java/com/sun/gluegen/GlueEmitter.java
+++ b/src/java/com/jogamp/gluegen/GlueEmitter.java
@@ -37,10 +37,10 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.util.*;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.types.*;
/** Specifies the interface by which GlueGen requests glue code to be
generated. Can be replaced to generate glue code for other
diff --git a/src/java/com/sun/gluegen/GlueEmitterControls.java b/src/java/com/jogamp/gluegen/GlueEmitterControls.java
index 659a4ee..07b370d 100644
--- a/src/java/com/sun/gluegen/GlueEmitterControls.java
+++ b/src/java/com/jogamp/gluegen/GlueEmitterControls.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
/** Specifies the interface by which a GlueEmitter can request
additional information from the glue generator. */
diff --git a/src/java/com/sun/gluegen/GlueGen.java b/src/java/com/jogamp/gluegen/GlueGen.java
index b03109c..901dd86 100644
--- a/src/java/com/sun/gluegen/GlueGen.java
+++ b/src/java/com/jogamp/gluegen/GlueGen.java
@@ -37,15 +37,15 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.io.*;
import java.util.*;
import antlr.*;
-import com.sun.gluegen.cgram.*;
-import com.sun.gluegen.cgram.types.*;
-import com.sun.gluegen.pcpp.*;
+import com.jogamp.gluegen.cgram.*;
+import com.jogamp.gluegen.cgram.types.*;
+import com.jogamp.gluegen.pcpp.*;
import static java.lang.System.*;
@@ -385,8 +385,8 @@ public class GlueGen implements GlueEmitterControls {
out.println("passing input through minimal pseudo-C-preprocessor. Use -I");
out.println("command-line arguments to specify the search path for #includes.");
out.println("Emitter class name can be specified with -E option: i.e.,");
- out.println("-Ecom.sun.gluegen.JavaEmitter (the default). Use");
- out.println("-Ecom.sun.gluegen.DebugEmitter to print recognized entities");
+ out.println("-Ecom.jogamp.gluegen.JavaEmitter (the default). Use");
+ out.println("-Ecom.jogamp.gluegen.DebugEmitter to print recognized entities");
out.println("(#define directives to constant numbers, typedefs, and function");
out.println("declarations) to standard output. Emitter-specific configuration");
out.println("file or files can be specified with -C option; e.g,");
diff --git a/src/java/com/sun/gluegen/JavaConfiguration.java b/src/java/com/jogamp/gluegen/JavaConfiguration.java
index f4cf0bd..5323c77 100644
--- a/src/java/com/sun/gluegen/JavaConfiguration.java
+++ b/src/java/com/jogamp/gluegen/JavaConfiguration.java
@@ -38,23 +38,23 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.JavaEmitter.EmissionStyle;
-import com.sun.gluegen.JavaEmitter.MethodAccess;
+import com.jogamp.gluegen.JavaEmitter.EmissionStyle;
+import com.jogamp.gluegen.JavaEmitter.MethodAccess;
import java.io.*;
import java.lang.reflect.Array;
import java.util.*;
import java.util.Map.Entry;
import java.util.regex.*;
-import com.sun.gluegen.jgram.*;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.jgram.*;
+import com.jogamp.gluegen.cgram.types.*;
import java.util.logging.Logger;
import static java.util.logging.Level.*;
-import static com.sun.gluegen.JavaEmitter.MethodAccess.*;
-import static com.sun.gluegen.JavaEmitter.EmissionStyle.*;
+import static com.jogamp.gluegen.JavaEmitter.MethodAccess.*;
+import static com.jogamp.gluegen.JavaEmitter.EmissionStyle.*;
/** Parses and provides access to the contents of .cfg files for the
JavaEmitter. */
diff --git a/src/java/com/sun/gluegen/JavaEmitter.java b/src/java/com/jogamp/gluegen/JavaEmitter.java
index 5fc07b0..250da79 100644
--- a/src/java/com/sun/gluegen/JavaEmitter.java
+++ b/src/java/com/jogamp/gluegen/JavaEmitter.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import com.jogamp.common.nio.Buffers;
import com.jogamp.common.os.DynamicLookupHelper;
@@ -46,12 +46,12 @@ import java.io.*;
import java.util.*;
import java.text.MessageFormat;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.types.*;
import java.nio.Buffer;
import java.util.logging.Logger;
import static java.util.logging.Level.*;
-import static com.sun.gluegen.JavaEmitter.MethodAccess.*;
+import static com.jogamp.gluegen.JavaEmitter.MethodAccess.*;
// PROBLEMS:
// - what if something returns 'const int *'? Could we
diff --git a/src/java/com/sun/gluegen/JavaMethodBindingEmitter.java b/src/java/com/jogamp/gluegen/JavaMethodBindingEmitter.java
index f7bbc99..3bf3dc1 100644
--- a/src/java/com/sun/gluegen/JavaMethodBindingEmitter.java
+++ b/src/java/com/jogamp/gluegen/JavaMethodBindingEmitter.java
@@ -37,14 +37,14 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.io.*;
import java.util.*;
import java.text.MessageFormat;
-import com.sun.gluegen.cgram.types.*;
-import com.sun.gluegen.cgram.*;
+import com.jogamp.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.*;
/**
* An emitter that emits only the interface for a Java<->C JNI binding.
diff --git a/src/java/com/sun/gluegen/JavaType.java b/src/java/com/jogamp/gluegen/JavaType.java
index a7e9fcf..9a89203 100644
--- a/src/java/com/sun/gluegen/JavaType.java
+++ b/src/java/com/jogamp/gluegen/JavaType.java
@@ -38,11 +38,11 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.nio.*;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.types.*;
/**
* Describes a java-side representation of a type that is used to represent
diff --git a/src/java/com/sun/gluegen/Logging.java b/src/java/com/jogamp/gluegen/Logging.java
index c6e5e3b..9ad3bf7 100644
--- a/src/java/com/sun/gluegen/Logging.java
+++ b/src/java/com/jogamp/gluegen/Logging.java
@@ -29,7 +29,7 @@
/*
* Created on Wednesday, March 31 2010 13:30
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.util.logging.ConsoleHandler;
import java.util.logging.Formatter;
diff --git a/src/java/com/sun/gluegen/MethodBinding.java b/src/java/com/jogamp/gluegen/MethodBinding.java
index 7b3984e..a8d4b30 100644
--- a/src/java/com/sun/gluegen/MethodBinding.java
+++ b/src/java/com/jogamp/gluegen/MethodBinding.java
@@ -37,10 +37,10 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.cgram.types.FunctionSymbol;
-import com.sun.gluegen.cgram.types.Type;
+import com.jogamp.gluegen.cgram.types.FunctionSymbol;
+import com.jogamp.gluegen.cgram.types.Type;
import java.util.ArrayList;
import java.util.Collection;
diff --git a/src/java/com/sun/gluegen/ReferencedStructs.java b/src/java/com/jogamp/gluegen/ReferencedStructs.java
index 21d1142..b8a176f 100644
--- a/src/java/com/sun/gluegen/ReferencedStructs.java
+++ b/src/java/com/jogamp/gluegen/ReferencedStructs.java
@@ -37,10 +37,10 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.util.*;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.types.*;
public class ReferencedStructs implements TypeVisitor {
diff --git a/src/java/com/sun/gluegen/StructLayout.java b/src/java/com/jogamp/gluegen/StructLayout.java
index 111c19f..ea8768f 100644
--- a/src/java/com/sun/gluegen/StructLayout.java
+++ b/src/java/com/jogamp/gluegen/StructLayout.java
@@ -37,9 +37,9 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.cgram.types.*;
/** Encapsulates algorithm for laying out data structures. Note that
this ends up embedding code in various places via SizeThunks. If
diff --git a/src/java/com/sun/gluegen/TypeInfo.java b/src/java/com/jogamp/gluegen/TypeInfo.java
index 10df349..b62fc15 100644
--- a/src/java/com/sun/gluegen/TypeInfo.java
+++ b/src/java/com/jogamp/gluegen/TypeInfo.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
/** Utility class for handling Opaque directives for JavaEmitter. */
diff --git a/src/java/com/sun/gluegen/cgram/CSymbolTable.java b/src/java/com/jogamp/gluegen/cgram/CSymbolTable.java
index 51edf44..0addf7b 100644
--- a/src/java/com/sun/gluegen/cgram/CSymbolTable.java
+++ b/src/java/com/jogamp/gluegen/cgram/CSymbolTable.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.cgram;
+package com.jogamp.gluegen.cgram;
import java.util.Vector;
import java.util.Hashtable;
diff --git a/src/java/com/sun/gluegen/cgram/CToken.java b/src/java/com/jogamp/gluegen/cgram/CToken.java
index 5d85c48..f6bbf51 100644
--- a/src/java/com/sun/gluegen/cgram/CToken.java
+++ b/src/java/com/jogamp/gluegen/cgram/CToken.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.cgram;
+package com.jogamp.gluegen.cgram;
import antlr.CommonToken;
diff --git a/src/java/com/sun/gluegen/cgram/Define.java b/src/java/com/jogamp/gluegen/cgram/Define.java
index a71c538..c2510df 100644
--- a/src/java/com/sun/gluegen/cgram/Define.java
+++ b/src/java/com/jogamp/gluegen/cgram/Define.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram;
+package com.jogamp.gluegen.cgram;
/** Represents a #define of a literal to a value (a number represented
in string form.) */
diff --git a/src/java/com/sun/gluegen/cgram/GnuCEmitter.g b/src/java/com/jogamp/gluegen/cgram/GnuCEmitter.g
index 82003c3..78f8d68 100644
--- a/src/java/com/sun/gluegen/cgram/GnuCEmitter.g
+++ b/src/java/com/jogamp/gluegen/cgram/GnuCEmitter.g
@@ -17,7 +17,7 @@ DESCRIPTION:
header {
- package com.sun.gluegen.cgram;
+ package com.jogamp.gluegen.cgram;
import java.io.*;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/cgram/GnuCParser.g b/src/java/com/jogamp/gluegen/cgram/GnuCParser.g
index 7b4c8f8..f795702 100644
--- a/src/java/com/sun/gluegen/cgram/GnuCParser.g
+++ b/src/java/com/jogamp/gluegen/cgram/GnuCParser.g
@@ -17,7 +17,7 @@ DESCRIPTION:
header {
- package com.sun.gluegen.cgram;
+ package com.jogamp.gluegen.cgram;
import java.io.*;
diff --git a/src/java/com/sun/gluegen/cgram/GnuCTreeParser.g b/src/java/com/jogamp/gluegen/cgram/GnuCTreeParser.g
index 5231dee..82792f3 100644
--- a/src/java/com/sun/gluegen/cgram/GnuCTreeParser.g
+++ b/src/java/com/jogamp/gluegen/cgram/GnuCTreeParser.g
@@ -17,7 +17,7 @@ DESCRIPTION:
header {
- package com.sun.gluegen.cgram;
+ package com.jogamp.gluegen.cgram;
import java.io.*;
diff --git a/src/java/com/sun/gluegen/cgram/HeaderParser.g b/src/java/com/jogamp/gluegen/cgram/HeaderParser.g
index 9040c29..fa6455f 100644
--- a/src/java/com/sun/gluegen/cgram/HeaderParser.g
+++ b/src/java/com/jogamp/gluegen/cgram/HeaderParser.g
@@ -39,13 +39,13 @@
*/
header {
- package com.sun.gluegen.cgram;
+ package com.jogamp.gluegen.cgram;
import java.io.*;
import java.util.*;
import antlr.CommonAST;
- import com.sun.gluegen.cgram.types.*;
+ import com.jogamp.gluegen.cgram.types.*;
}
class HeaderParser extends GnuCTreeParser;
diff --git a/src/java/com/sun/gluegen/cgram/LineObject.java b/src/java/com/jogamp/gluegen/cgram/LineObject.java
index 0ed470c..c03b3e8 100644
--- a/src/java/com/sun/gluegen/cgram/LineObject.java
+++ b/src/java/com/jogamp/gluegen/cgram/LineObject.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.cgram;
+package com.jogamp.gluegen.cgram;
class LineObject {
LineObject parent = null;
diff --git a/src/java/com/sun/gluegen/cgram/PreprocessorInfoChannel.java b/src/java/com/jogamp/gluegen/cgram/PreprocessorInfoChannel.java
index 431af91..5e7018f 100644
--- a/src/java/com/sun/gluegen/cgram/PreprocessorInfoChannel.java
+++ b/src/java/com/jogamp/gluegen/cgram/PreprocessorInfoChannel.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.cgram;
+package com.jogamp.gluegen.cgram;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/cgram/StdCParser.g b/src/java/com/jogamp/gluegen/cgram/StdCParser.g
index 65e7936..015c3e0 100644
--- a/src/java/com/sun/gluegen/cgram/StdCParser.g
+++ b/src/java/com/jogamp/gluegen/cgram/StdCParser.g
@@ -47,7 +47,7 @@ TODO:
header {
- package com.sun.gluegen.cgram;
+ package com.jogamp.gluegen.cgram;
import java.io.*;
diff --git a/src/java/com/sun/gluegen/cgram/TNode.java b/src/java/com/jogamp/gluegen/cgram/TNode.java
index 9fca506..e9185f9 100644
--- a/src/java/com/sun/gluegen/cgram/TNode.java
+++ b/src/java/com/jogamp/gluegen/cgram/TNode.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.cgram;
+package com.jogamp.gluegen.cgram;
import antlr.collections.AST;
import antlr.CommonAST;
diff --git a/src/java/com/sun/gluegen/cgram/TNodeFactory.java b/src/java/com/jogamp/gluegen/cgram/TNodeFactory.java
index 4523632..0a3fbcb 100644
--- a/src/java/com/sun/gluegen/cgram/TNodeFactory.java
+++ b/src/java/com/jogamp/gluegen/cgram/TNodeFactory.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.cgram;
+package com.jogamp.gluegen.cgram;
import antlr.Token;
import antlr.ASTFactory;
diff --git a/src/java/com/sun/gluegen/cgram/types/ArrayType.java b/src/java/com/jogamp/gluegen/cgram/types/ArrayType.java
index 6ef4682..675efb5 100644
--- a/src/java/com/sun/gluegen/cgram/types/ArrayType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/ArrayType.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Represents an array type. This differs from a pointer type in C
syntax by the use of "[]" rather than "*". The length may or may
diff --git a/src/java/com/sun/gluegen/cgram/types/BitType.java b/src/java/com/jogamp/gluegen/cgram/types/BitType.java
index fc6f851..a7a1f55 100644
--- a/src/java/com/sun/gluegen/cgram/types/BitType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/BitType.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Represents a bitfield in a struct. */
diff --git a/src/java/com/sun/gluegen/cgram/types/CVAttributes.java b/src/java/com/jogamp/gluegen/cgram/types/CVAttributes.java
index 589904b..34b703e 100644
--- a/src/java/com/sun/gluegen/cgram/types/CVAttributes.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/CVAttributes.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Enumeration for const/volatile attributes. These are passed in to
the constructor of the type. */
diff --git a/src/java/com/sun/gluegen/cgram/types/CompoundType.java b/src/java/com/jogamp/gluegen/cgram/types/CompoundType.java
index 0a880de..9e9ead7 100644
--- a/src/java/com/sun/gluegen/cgram/types/CompoundType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/CompoundType.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/cgram/types/CompoundTypeKind.java b/src/java/com/jogamp/gluegen/cgram/types/CompoundTypeKind.java
index 8df12ac..b07611c 100644
--- a/src/java/com/sun/gluegen/cgram/types/CompoundTypeKind.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/CompoundTypeKind.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Type-safe enum for discriminating between structs and unions,
which are both represented as compound types. */
diff --git a/src/java/com/sun/gluegen/cgram/types/DoubleType.java b/src/java/com/jogamp/gluegen/cgram/types/DoubleType.java
index cc4ffba..280485a 100644
--- a/src/java/com/sun/gluegen/cgram/types/DoubleType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/DoubleType.java
@@ -37,7 +37,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Represents a double-word floating-point type (C type "double".) */
public class DoubleType extends PrimitiveType implements Cloneable {
diff --git a/src/java/com/sun/gluegen/cgram/types/EnumType.java b/src/java/com/jogamp/gluegen/cgram/types/EnumType.java
index 49f962d..7967ba0 100644
--- a/src/java/com/sun/gluegen/cgram/types/EnumType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/EnumType.java
@@ -37,7 +37,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
import java.util.ArrayList;
import java.util.NoSuchElementException;
diff --git a/src/java/com/sun/gluegen/cgram/types/Field.java b/src/java/com/jogamp/gluegen/cgram/types/Field.java
index dd7ecff..07d90ea 100644
--- a/src/java/com/sun/gluegen/cgram/types/Field.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/Field.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Represents a field in a struct or union. */
diff --git a/src/java/com/sun/gluegen/cgram/types/FloatType.java b/src/java/com/jogamp/gluegen/cgram/types/FloatType.java
index 2e80be9..7766b8c 100644
--- a/src/java/com/sun/gluegen/cgram/types/FloatType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/FloatType.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Represents a single-word floating-point type (C type "float".) */
diff --git a/src/java/com/sun/gluegen/cgram/types/FunctionSymbol.java b/src/java/com/jogamp/gluegen/cgram/types/FunctionSymbol.java
index 730674a..545a6e8 100644
--- a/src/java/com/sun/gluegen/cgram/types/FunctionSymbol.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/FunctionSymbol.java
@@ -36,7 +36,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Describes a function symbol, which includes the name and
type. Since we are currently only concerned with processing
diff --git a/src/java/com/sun/gluegen/cgram/types/FunctionType.java b/src/java/com/jogamp/gluegen/cgram/types/FunctionType.java
index 3b09d8b..cb430db 100644
--- a/src/java/com/sun/gluegen/cgram/types/FunctionType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/FunctionType.java
@@ -37,7 +37,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/cgram/types/IntType.java b/src/java/com/jogamp/gluegen/cgram/types/IntType.java
index fbbd939..c72fde4 100644
--- a/src/java/com/sun/gluegen/cgram/types/IntType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/IntType.java
@@ -37,7 +37,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public class IntType extends PrimitiveType implements Cloneable {
diff --git a/src/java/com/sun/gluegen/cgram/types/MachineDescription.java b/src/java/com/jogamp/gluegen/cgram/types/MachineDescription.java
index b3aaf53..d2598e0 100644
--- a/src/java/com/sun/gluegen/cgram/types/MachineDescription.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/MachineDescription.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public class MachineDescription {
private int charSizeInBytes;
diff --git a/src/java/com/sun/gluegen/cgram/types/MachineDescription32Bit.java b/src/java/com/jogamp/gluegen/cgram/types/MachineDescription32Bit.java
index 7b8f12d..6bbb801 100644
--- a/src/java/com/sun/gluegen/cgram/types/MachineDescription32Bit.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/MachineDescription32Bit.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public class MachineDescription32Bit extends MachineDescription {
public MachineDescription32Bit() {
diff --git a/src/java/com/sun/gluegen/cgram/types/MachineDescription64Bit.java b/src/java/com/jogamp/gluegen/cgram/types/MachineDescription64Bit.java
index 1036399..38328e4 100644
--- a/src/java/com/sun/gluegen/cgram/types/MachineDescription64Bit.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/MachineDescription64Bit.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public class MachineDescription64Bit extends MachineDescription {
public MachineDescription64Bit() {
diff --git a/src/java/com/sun/gluegen/cgram/types/PointerType.java b/src/java/com/jogamp/gluegen/cgram/types/PointerType.java
index cfd54c5..4666e48 100644
--- a/src/java/com/sun/gluegen/cgram/types/PointerType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/PointerType.java
@@ -37,7 +37,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public class PointerType extends Type implements Cloneable {
diff --git a/src/java/com/sun/gluegen/cgram/types/PrimitiveType.java b/src/java/com/jogamp/gluegen/cgram/types/PrimitiveType.java
index 27cd3dd..1eea9a4 100644
--- a/src/java/com/sun/gluegen/cgram/types/PrimitiveType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/PrimitiveType.java
@@ -37,7 +37,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public abstract class PrimitiveType extends Type implements Cloneable {
diff --git a/src/java/com/sun/gluegen/cgram/types/SizeThunk.java b/src/java/com/jogamp/gluegen/cgram/types/SizeThunk.java
index fcc96be..40ddd57 100755
--- a/src/java/com/sun/gluegen/cgram/types/SizeThunk.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/SizeThunk.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
/** Provides a level of indirection between the definition of a type's
size and the absolute value of this size. Necessary when
diff --git a/src/java/com/sun/gluegen/cgram/types/Type.java b/src/java/com/jogamp/gluegen/cgram/types/Type.java
index e43acb2..c58bfae 100644
--- a/src/java/com/sun/gluegen/cgram/types/Type.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/Type.java
@@ -38,7 +38,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
import java.util.List;
diff --git a/src/java/com/sun/gluegen/cgram/types/TypeDictionary.java b/src/java/com/jogamp/gluegen/cgram/types/TypeDictionary.java
index 256b5ce..3bc4d87 100644
--- a/src/java/com/sun/gluegen/cgram/types/TypeDictionary.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/TypeDictionary.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/cgram/types/TypeVisitor.java b/src/java/com/jogamp/gluegen/cgram/types/TypeVisitor.java
index 88f7dd5..0889681 100644
--- a/src/java/com/sun/gluegen/cgram/types/TypeVisitor.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/TypeVisitor.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public interface TypeVisitor {
public void visitType(Type t);
diff --git a/src/java/com/sun/gluegen/cgram/types/VoidType.java b/src/java/com/jogamp/gluegen/cgram/types/VoidType.java
index 4c3c077..fa098e7 100644
--- a/src/java/com/sun/gluegen/cgram/types/VoidType.java
+++ b/src/java/com/jogamp/gluegen/cgram/types/VoidType.java
@@ -37,7 +37,7 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.cgram.types;
+package com.jogamp.gluegen.cgram.types;
public class VoidType extends Type implements Cloneable {
diff --git a/src/java/com/sun/gluegen/jgram/JavaParser.g b/src/java/com/jogamp/gluegen/jgram/JavaParser.g
index e3a1962..18f2970 100644
--- a/src/java/com/sun/gluegen/jgram/JavaParser.g
+++ b/src/java/com/jogamp/gluegen/jgram/JavaParser.g
@@ -119,7 +119,7 @@
*/
header {
- package com.sun.gluegen.jgram;
+ package com.jogamp.gluegen.jgram;
import java.util.*;
diff --git a/src/java/com/sun/gluegen/jgram/Test.java b/src/java/com/jogamp/gluegen/jgram/Test.java
index 996d645..c890f67 100644
--- a/src/java/com/sun/gluegen/jgram/Test.java
+++ b/src/java/com/jogamp/gluegen/jgram/Test.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.jgram;
+package com.jogamp.gluegen.jgram;
import java.util.*;
@@ -29,7 +29,7 @@ class Test {
}
} }
else
- System.err.println("Usage: java com.sun.gluegen.jgram.Test [-showtree] "+
+ System.err.println("Usage: java com.jogamp.gluegen.jgram.Test [-showtree] "+
"<directory or file name>");
}
catch(Exception e) {
diff --git a/src/java/com/sun/gluegen/nativesig/NativeSignatureEmitter.java b/src/java/com/jogamp/gluegen/nativesig/NativeSignatureEmitter.java
index f20495b..bbc33d7 100755
--- a/src/java/com/sun/gluegen/nativesig/NativeSignatureEmitter.java
+++ b/src/java/com/jogamp/gluegen/nativesig/NativeSignatureEmitter.java
@@ -36,15 +36,19 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.nativesig;
+package com.jogamp.gluegen.nativesig;
+import com.jogamp.gluegen.MethodBinding;
+import com.jogamp.gluegen.FunctionEmitter;
+import com.jogamp.gluegen.JavaMethodBindingEmitter;
+import com.jogamp.gluegen.JavaType;
import java.io.*;
import java.util.*;
-import com.sun.gluegen.*;
-import com.sun.gluegen.cgram.types.*;
-import com.sun.gluegen.opengl.*;
-import com.sun.gluegen.procaddress.*;
+import com.jogamp.gluegen.*;
+import com.jogamp.gluegen.cgram.types.*;
+import com.jogamp.gluegen.opengl.*;
+import com.jogamp.gluegen.procaddress.*;
/**
* Emitter producing NativeSignature attributes.
diff --git a/src/java/com/sun/gluegen/nativesig/NativeSignatureJavaMethodBindingEmitter.java b/src/java/com/jogamp/gluegen/nativesig/NativeSignatureJavaMethodBindingEmitter.java
index 379eccf..060d008 100755
--- a/src/java/com/sun/gluegen/nativesig/NativeSignatureJavaMethodBindingEmitter.java
+++ b/src/java/com/jogamp/gluegen/nativesig/NativeSignatureJavaMethodBindingEmitter.java
@@ -37,14 +37,17 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.nativesig;
+package com.jogamp.gluegen.nativesig;
+import com.jogamp.gluegen.MethodBinding;
+import com.jogamp.gluegen.JavaMethodBindingEmitter;
+import com.jogamp.gluegen.JavaType;
import java.io.*;
-import com.sun.gluegen.*;
-import com.sun.gluegen.cgram.types.*;
-import com.sun.gluegen.opengl.*;
-import com.sun.gluegen.procaddress.*;
+import com.jogamp.gluegen.*;
+import com.jogamp.gluegen.cgram.types.*;
+import com.jogamp.gluegen.opengl.*;
+import com.jogamp.gluegen.procaddress.*;
public class NativeSignatureJavaMethodBindingEmitter extends GLJavaMethodBindingEmitter {
diff --git a/src/java/com/sun/gluegen/pcpp/ConcatenatingReader.java b/src/java/com/jogamp/gluegen/pcpp/ConcatenatingReader.java
index 6da77be..1eea281 100755
--- a/src/java/com/sun/gluegen/pcpp/ConcatenatingReader.java
+++ b/src/java/com/jogamp/gluegen/pcpp/ConcatenatingReader.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.pcpp;
+package com.jogamp.gluegen.pcpp;
import java.io.*;
diff --git a/src/java/com/sun/gluegen/pcpp/PCPP.java b/src/java/com/jogamp/gluegen/pcpp/PCPP.java
index cced7a6..ab2c8b2 100644
--- a/src/java/com/sun/gluegen/pcpp/PCPP.java
+++ b/src/java/com/jogamp/gluegen/pcpp/PCPP.java
@@ -37,7 +37,7 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.pcpp;
+package com.jogamp.gluegen.pcpp;
import java.io.BufferedReader;
diff --git a/src/java/com/sun/gluegen/procaddress/ProcAddressCMethodBindingEmitter.java b/src/java/com/jogamp/gluegen/procaddress/ProcAddressCMethodBindingEmitter.java
index a951c42..fedb1e6 100755
--- a/src/java/com/sun/gluegen/procaddress/ProcAddressCMethodBindingEmitter.java
+++ b/src/java/com/jogamp/gluegen/procaddress/ProcAddressCMethodBindingEmitter.java
@@ -37,11 +37,14 @@
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.procaddress;
+package com.jogamp.gluegen.procaddress;
+import com.jogamp.gluegen.CMethodBindingEmitter;
+import com.jogamp.gluegen.MethodBinding;
+import com.jogamp.gluegen.JavaType;
import java.io.*;
-import com.sun.gluegen.*;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.*;
+import com.jogamp.gluegen.cgram.types.*;
public class ProcAddressCMethodBindingEmitter extends CMethodBindingEmitter {
diff --git a/src/java/com/sun/gluegen/procaddress/ProcAddressConfiguration.java b/src/java/com/jogamp/gluegen/procaddress/ProcAddressConfiguration.java
index 993f917..51e3166 100755
--- a/src/java/com/sun/gluegen/procaddress/ProcAddressConfiguration.java
+++ b/src/java/com/jogamp/gluegen/procaddress/ProcAddressConfiguration.java
@@ -36,13 +36,14 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.procaddress;
+package com.jogamp.gluegen.procaddress;
+import com.jogamp.gluegen.JavaConfiguration;
import java.io.*;
import java.text.*;
import java.util.*;
-import com.sun.gluegen.*;
+import com.jogamp.gluegen.*;
public class ProcAddressConfiguration extends JavaConfiguration {
diff --git a/src/java/com/sun/gluegen/procaddress/ProcAddressEmitter.java b/src/java/com/jogamp/gluegen/procaddress/ProcAddressEmitter.java
index 9094f14..c07dab7 100755
--- a/src/java/com/sun/gluegen/procaddress/ProcAddressEmitter.java
+++ b/src/java/com/jogamp/gluegen/procaddress/ProcAddressEmitter.java
@@ -36,13 +36,20 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.procaddress;
-
+package com.jogamp.gluegen.procaddress;
+
+import com.jogamp.gluegen.CMethodBindingEmitter;
+import com.jogamp.gluegen.JavaConfiguration;
+import com.jogamp.gluegen.MethodBinding;
+import com.jogamp.gluegen.FunctionEmitter;
+import com.jogamp.gluegen.CodeGenUtils;
+import com.jogamp.gluegen.JavaMethodBindingEmitter;
+import com.jogamp.gluegen.JavaEmitter;
import java.io.*;
import java.text.MessageFormat;
import java.util.*;
-import com.sun.gluegen.*;
-import com.sun.gluegen.cgram.types.*;
+import com.jogamp.gluegen.*;
+import com.jogamp.gluegen.cgram.types.*;
import com.jogamp.gluegen.runtime.*;
/**
diff --git a/src/java/com/sun/gluegen/procaddress/ProcAddressJavaMethodBindingEmitter.java b/src/java/com/jogamp/gluegen/procaddress/ProcAddressJavaMethodBindingEmitter.java
index 5a30ee5..443c1d8 100755
--- a/src/java/com/sun/gluegen/procaddress/ProcAddressJavaMethodBindingEmitter.java
+++ b/src/java/com/jogamp/gluegen/procaddress/ProcAddressJavaMethodBindingEmitter.java
@@ -36,10 +36,13 @@
* Sun gratefully acknowledges that this software was originally authored
* and developed by Kenneth Bradley Russell and Christopher John Kline.
*/
-package com.sun.gluegen.procaddress;
+package com.jogamp.gluegen.procaddress;
+import com.jogamp.gluegen.MethodBinding;
+import com.jogamp.gluegen.FunctionEmitter;
+import com.jogamp.gluegen.JavaMethodBindingEmitter;
import java.io.*;
-import com.sun.gluegen.*;
+import com.jogamp.gluegen.*;
/** A specialization of JavaMethodBindingEmitter with knowledge of how
to call through a function pointer. */
diff --git a/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java b/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java
index 5b32916..10156f9 100644
--- a/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java
+++ b/test/junit/com/sun/gluegen/BasicProcAddressEmitterTest.java
@@ -26,16 +26,16 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.procaddress.ProcAddressEmitter;
+import com.jogamp.gluegen.procaddress.ProcAddressEmitter;
import java.lang.reflect.Field;
import java.util.HashSet;
import java.util.Set;
import org.junit.AfterClass;
import org.junit.Test;
import static java.util.Arrays.*;
-import static com.sun.gluegen.BuildUtil.*;
+import static com.jogamp.gluegen.BuildUtil.*;
import static org.junit.Assert.*;
/**
diff --git a/test/junit/com/sun/gluegen/BasicTest.java b/test/junit/com/sun/gluegen/BasicTest.java
index 42096db..38bb7f9 100644
--- a/test/junit/com/sun/gluegen/BasicTest.java
+++ b/test/junit/com/sun/gluegen/BasicTest.java
@@ -26,7 +26,7 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import com.jogamp.common.nio.Buffers;
import com.jogamp.common.nio.PointerBuffer;
@@ -38,7 +38,7 @@ import org.junit.AfterClass;
import org.junit.Test;
import static org.junit.Assert.*;
import static java.lang.System.*;
-import static com.sun.gluegen.BuildUtil.*;
+import static com.jogamp.gluegen.BuildUtil.*;
/**
*
diff --git a/test/junit/com/sun/gluegen/BuildUtil.java b/test/junit/com/sun/gluegen/BuildUtil.java
index 76de30f..ce88ba2 100644
--- a/test/junit/com/sun/gluegen/BuildUtil.java
+++ b/test/junit/com/sun/gluegen/BuildUtil.java
@@ -26,8 +26,10 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
+import com.jogamp.gluegen.JavaEmitter;
+import com.jogamp.gluegen.GlueGen;
import java.io.File;
import java.net.URISyntaxException;
import org.apache.tools.ant.DefaultLogger;
@@ -71,7 +73,7 @@ public final class BuildUtil {
throw new RuntimeException("can not determine gluegen root", ex);
}
- path = gluegenRoot + "/test/junit/com/sun/gluegen";
+ path = gluegenRoot + "/test/junit/com/jogamp/gluegen";
testOutput = gluegenRoot + "/" + rootrel_build + "/test";
out.println("path: "+path);
diff --git a/test/junit/com/sun/gluegen/PCPPTest.java b/test/junit/com/sun/gluegen/PCPPTest.java
index deea0d8..c1f12ab 100644
--- a/test/junit/com/sun/gluegen/PCPPTest.java
+++ b/test/junit/com/sun/gluegen/PCPPTest.java
@@ -26,9 +26,9 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.pcpp.PCPP;
+import com.jogamp.gluegen.pcpp.PCPP;
import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.FileNotFoundException;
diff --git a/test/junit/com/sun/gluegen/StructAccessorTest.java b/test/junit/com/sun/gluegen/StructAccessorTest.java
index 9c50673..4d1bffd 100644
--- a/test/junit/com/sun/gluegen/StructAccessorTest.java
+++ b/test/junit/com/sun/gluegen/StructAccessorTest.java
@@ -26,7 +26,7 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.io.File;
import java.io.IOException;
@@ -45,7 +45,7 @@ import junit.framework.Assert;
import org.junit.AfterClass;
import org.junit.Test;
import static java.lang.System.*;
-import static com.sun.gluegen.BuildUtil.*;
+import static com.jogamp.gluegen.BuildUtil.*;
/**
*
@@ -73,11 +73,11 @@ public class StructAccessorTest {
public void validateGeneratedStructs() throws IOException, NoSuchMethodException, ClassNotFoundException, IllegalAccessException, InvocationTargetException {
// compile testcase
- String source = gluegenRoot + "/test/junit/com/sun/gluegen/StructValidator.java";
+ String source = gluegenRoot + "/test/junit/com/jogamp/gluegen/StructValidator.java";
compile(new File(source), testOutput + "/build/classes");
// invoke test
- Class<?> test = Class.forName("com.sun.gluegen.StructValidator");
+ Class<?> test = Class.forName("com.jogamp.gluegen.StructValidator");
test.getDeclaredMethod("validate").invoke(null);
}
diff --git a/test/junit/com/sun/gluegen/build.xml b/test/junit/com/sun/gluegen/build.xml
index 6622e0c..95617be 100644
--- a/test/junit/com/sun/gluegen/build.xml
+++ b/test/junit/com/sun/gluegen/build.xml
@@ -64,12 +64,12 @@
rtti="false"
failonerror="true">
- <fileset dir="${gluegen.root}/test/junit/com/sun/gluegen" includes="*.c"/>
+ <fileset dir="${gluegen.root}/test/junit/com/jogamp/gluegen" includes="*.c"/>
<compiler extends="${compiler.cfg.id}" >
<includepath path="${java.includes.dir}"/>
<includepath path="${java.includes.dir.platform}"/>
- <includepath path="${gluegen.root}/test/junit/com/sun/gluegen"/>
+ <includepath path="${gluegen.root}/test/junit/com/jogamp/gluegen"/>
</compiler>
<linker extends="${linker.cfg.id}">
diff --git a/src/java/com/sun/gluegen/SymbolFilter.java b/src/java/com/jogamp/gluegen/SymbolFilter.java
index dcac628..4e99caa 100644
--- a/src/java/com/sun/gluegen/SymbolFilter.java
+++ b/src/java/com/jogamp/gluegen/SymbolFilter.java
@@ -31,9 +31,9 @@
*
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
-import com.sun.gluegen.cgram.types.FunctionSymbol;
+import com.jogamp.gluegen.cgram.types.FunctionSymbol;
import java.util.List;
/** Provides a mechanism by which the GlueEmitter can look at all of
@@ -47,8 +47,8 @@ public interface SymbolFilter {
* will query the SymbolFilter for its resulting constant and
* function symbol lists after this routine returns.
*
* @param defines a list of {@link com.sun.gluegen.cgram.Define Define} objects
* @param functions a list of {@link com.sun.gluegen.cgram.types.FunctionSymbol FunctionSymbol} objects
*/
public void filterSymbols(List<ConstantDefinition> constants, List<FunctionSymbol> functions);
@@ -47,8 +47,8 @@ public interface SymbolFilter {
* function symbol lists after this routine returns.
*
- * @param defines a list of {@link com.sun.gluegen.cgram.Define Define} objects
- * @param functions a list of {@link com.sun.gluegen.cgram.types.FunctionSymbol FunctionSymbol} objects
+ * @param defines a list of {@link com.jogamp.gluegen.cgram.Define Define} objects
+ * @param functions a list of {@link com.jogamp.gluegen.cgram.types.FunctionSymbol FunctionSymbol} objects
*/
public void filterSymbols(List<ConstantDefinition> constants, List<FunctionSymbol> functions);
diff --git a/src/java/com/sun/gluegen/ant/GlueGenTask.java b/src/java/com/jogamp/gluegen/ant/GlueGenTask.java
index cc66c64..4cb88c2 100644
--- a/src/java/com/sun/gluegen/ant/GlueGenTask.java
+++ b/src/java/com/jogamp/gluegen/ant/GlueGenTask.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.ant;
+package com.jogamp.gluegen.ant;
/*
* GlueGenTask.java
@@ -60,7 +60,7 @@ import org.apache.tools.ant.util.JavaEnvUtils;
/**
* <p>An <a href="http://ant.apache.org">ANT</a> {@link org.apache.tools.ant.Task}
* for using {@link com.sun.gluegen.GlueGen}.</p>
*
* <p>Usage:</p>
* <pre>
@@ -82,14 +82,14 @@ import org.apache.tools.ant.util.JavaEnvUtils;
public class GlueGenTask extends Task
{
/**
- * <p>The {@link com.sun.gluegen.GlueGen} classname.</p>
+ * <p>The {@link com.jogamp.gluegen.GlueGen} classname.</p>
*/
- private static final String GLUE_GEN = "com.sun.gluegen.GlueGen";
+ private static final String GLUE_GEN = "com.jogamp.gluegen.GlueGen";
// =========================================================================
/**
* <p>The {@link org.apache.tools.ant.types.CommandlineJava} that is used
* to execute {@link com.sun.gluegen.GlueGen}.</p>
*/
private CommandlineJava gluegenCommandline;
@@ -339,7 +339,7 @@ public class GlueGenTask extends Task
}
/**
- * <p>Add an optional classpath that defines the location of {@link com.sun.gluegen.GlueGen}
+ * <p>Add an optional classpath that defines the location of {@link com.jogamp.gluegen.GlueGen}
* and <code>GlueGen</code>'s dependencies.</p>
*
* @returns {@link org.apache.tools.ant.types.Path}
@@ -513,7 +513,7 @@ public class GlueGenTask extends Task
}
/**
* <p>Execute {@link com.sun.gluegen.GlueGen} in a forked JVM.</p>
*
* @throws BuildException
*/
@@ -60,7 +60,7 @@ import org.apache.tools.ant.util.JavaEnvUtils;
/**
* <p>An <a href="http://ant.apache.org">ANT</a> {@link org.apache.tools.ant.Task}
- * for using {@link com.sun.gluegen.GlueGen}.</p>
+ * for using {@link com.jogamp.gluegen.GlueGen}.</p>
*
* <p>Usage:</p>
@@ -82,14 +82,14 @@ import org.apache.tools.ant.util.JavaEnvUtils;
/**
* <p>The {@link org.apache.tools.ant.types.CommandlineJava} that is used
- * to execute {@link com.sun.gluegen.GlueGen}.</p>
+ * to execute {@link com.jogamp.gluegen.GlueGen}.</p>
*/
private CommandlineJava gluegenCommandline;
@@ -513,7 +513,7 @@ public class GlueGenTask extends Task
}
/**
- * <p>Execute {@link com.sun.gluegen.GlueGen} in a forked JVM.</p>
+ * <p>Execute {@link com.jogamp.gluegen.GlueGen} in a forked JVM.</p>
*
* @throws BuildException
diff --git a/src/java/com/sun/gluegen/ant/StaticGLGenTask.java b/src/java/com/jogamp/gluegen/ant/StaticGLGenTask.java
index 8761942..2785344 100644
--- a/src/java/com/sun/gluegen/ant/StaticGLGenTask.java
+++ b/src/java/com/jogamp/gluegen/ant/StaticGLGenTask.java
@@ -1,4 +1,4 @@
-package com.sun.gluegen.ant;
+package com.jogamp.gluegen.ant;
/*
* StaticGLGenTask.java
@@ -55,7 +55,7 @@ import org.apache.tools.ant.util.JavaEnvUtils;
/**
* <p>An <a href="http://ant.apache.org">ANT</a> {@link org.apache.tools.ant.Task}
* for using {@link com.sun.gluegen.opengl.BuildStaticGLInfo}.</p>
*
* <p>Usage:</p>
* <pre>
@@ -70,14 +70,14 @@ import org.apache.tools.ant.util.JavaEnvUtils;
public class StaticGLGenTask extends Task
{
/**
- * <p>The {@link com.sun.gluegen.opengl.BuildStaticGLInfo} classname.</p>
+ * <p>The {@link com.jogamp.gluegen.opengl.BuildStaticGLInfo} classname.</p>
*/
- private static final String GL_GEN = "com.sun.gluegen.opengl.BuildStaticGLInfo";
+ private static final String GL_GEN = "com.jogamp.gluegen.opengl.BuildStaticGLInfo";
// =========================================================================
/**
* <p>The {@link org.apache.tools.ant.types.CommandlineJava} that is used
* to execute {@link com.sun.gluegen.opengl.BuildStaticGLInfo}.</p>
*/
private CommandlineJava glgenCommandline;
@@ -170,7 +170,7 @@ public class StaticGLGenTask extends Task
}
/**
- * <p>Add an optional classpath that defines the location of {@link com.sun.gluegen.opengl.BuildStaticGLInfo}
+ * <p>Add an optional classpath that defines the location of {@link com.jogamp.gluegen.opengl.BuildStaticGLInfo}
* and <code>BuildStaticGLInfo</code>'s dependencies.</p>
*
* @returns {@link org.apache.tools.ant.types.Path}
@@ -274,7 +274,7 @@ public class StaticGLGenTask extends Task
}
/**
- * <p>Execute {@link com.sun.gluegen.opengl.BuildStaticGLInfo} in a
+ * <p>Execute {@link com.jogamp.gluegen.opengl.BuildStaticGLInfo} in a
* forked JVM.</p>
*
* @throws BuildException
@@ -55,7 +55,7 @@ import org.apache.tools.ant.util.JavaEnvUtils;
/**
* <p>An <a href="http://ant.apache.org">ANT</a> {@link org.apache.tools.ant.Task}
- * for using {@link com.sun.gluegen.opengl.BuildStaticGLInfo}.</p>
+ * for using {@link com.jogamp.gluegen.opengl.BuildStaticGLInfo}.</p>
*
* <p>Usage:</p>
@@ -70,14 +70,14 @@ import org.apache.tools.ant.util.JavaEnvUtils;
/**
* <p>The {@link org.apache.tools.ant.types.CommandlineJava} that is used
- * to execute {@link com.sun.gluegen.opengl.BuildStaticGLInfo}.</p>
+ * to execute {@link com.jogamp.gluegen.opengl.BuildStaticGLInfo}.</p>
*/
private CommandlineJava glgenCommandline;
diff --git a/test/junit/com/sun/gluegen/StructValidator.java b/test/junit/com/sun/gluegen/StructValidator.java
index 9bdcbae..b6eb426 100644
--- a/test/junit/com/sun/gluegen/StructValidator.java
+++ b/test/junit/com/sun/gluegen/StructValidator.java
@@ -26,7 +26,7 @@
* or implied, of JogAmp Community.
*/
-package com.sun.gluegen;
+package com.jogamp.gluegen;
import java.lang.reflect.InvocationTargetException;
import org.junit.Ignore;
@@ -34,7 +34,7 @@ import org.junit.Ignore;
import static org.junit.Assert.*;
/**
* this file will not compile unless {@link com.sun.gluegen.StructAccessorTest} has been run.
* @author Michael Bien
*/
@Ignore
@@ -34,7 +34,7 @@ import org.junit.Ignore;
import static org.junit.Assert.*;
/**
- * this file will not compile unless {@link com.sun.gluegen.StructAccessorTest} has been run.
+ * this file will not compile unless {@link com.jogamp.gluegen.StructAccessorTest} has been run.
* @author Michael Bien
*/